name = "azure_translator_python3"
"""Azure Translator module."""
import http.client, urllib.parse, uuid, json, requests
from future.builtins import str


class Translator(object):
    host = 'api.cognitive.microsofttranslator.com'
    path = '/translate?api-version=3.0'

    def __init__(self, key):
        self.key = key

    def translate(self, content, target='en', source='en'):
        if type(content) == str:
            requestBody = [{
                'Text': content,
            }]
            content = json.dumps(requestBody, ensure_ascii=False).encode('utf-8')
            params = "&to=" + target
            if source:
                params += "&from=" + source
            headers = {
                'Ocp-Apim-Subscription-Key': self.key,
                'Content-type': 'application/json',
                'X-ClientTraceId': str(uuid.uuid4())
            }

            conn = http.client.HTTPSConnection(self.host)
            conn.request("POST", self.path + params, content, headers)
            response = conn.getresponse()
            return \
                json.loads(json.dumps(json.loads(response.read()), indent=4, ensure_ascii=False))[0]["translations"][0][
                    "text"]
        if type(content) == list:
            string_list = []
            for item in content:
                requestBody = [{
                    'Text': item,
                }]
                content = json.dumps(requestBody, ensure_ascii=False).encode('utf-8')
                params = "&to=" + target
                if source:
                    params += "&from=" + source
                headers = {
                    'Ocp-Apim-Subscription-Key': self.key,
                    'Content-type': 'application/json',
                    'X-ClientTraceId': str(uuid.uuid4())
                }

                conn = http.client.HTTPSConnection(self.host)
                conn.request("POST", self.path + params, content, headers)
                string_list.append(conn.getresponse().read())
            output_list = []
            for each_result in string_list:
                print(each_result)
                print(target)
                try:
                    output_list.append(json.loads(json.dumps(json.loads(each_result), indent=4, ensure_ascii=False))[0][
                                           "translations"][0]["text"])
                except KeyError:
                    output_list.append("")
            return output_list


if __name__ == "__main__":
    key = "300ffc1fe73c45b6a20d8ae753397281"
    t = Translator(key)
    print(t.translate("Сьешь же ещё этих мягких французских булочек да выпей же чаю",target='en',source='ru'))



from setuptools import setup

long_description = open("azure_translate/README.md").read()
setup(
    name='azure_translate',  # How you named your package folder (MyLib)
    packages=['azure_translate'],  # Chose the same as "name"
    package_data={
        'azure_translate': ['*.hy', '*.md', '*.py']
    },
    version='0.1',  # Start with a small number and increase it with every change you make
    license='MIT',  # Chose a license from here: https://help.github.com/articles/licensing-a-repository
    description='Azure translate engine',  # Give a short description about your library
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='ShinSheel',  # Type in your name
    author_email='wladgavrilov@gmail.com',  # Type in your E-Mail
    url='https://github.com/user/reponame',  # Provide either the link to your github or to your website
    download_url='https://github.com/user/reponame/archive/v_01.tar.gz',  # I explain this later on
    keywords=['Qwant', 'search', 'engine'],  # Keywords that define your package best
    install_requires=[  # I get to this in a second
        'requests'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package

        'Intended Audience :: Developers',  # Define that your audience are developers
        'Topic :: Software Development :: Build Tools',

        'License :: OSI Approved :: MIT License',  # Again, pick a license

        'Programming Language :: Python :: 3',  # Specify which pyhton versions that you want to support
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
)
